// Licensed Materials - Use restricted, For use in compiling interfaces to IBM Rational TestManager.  
//  Copyright IBM Corporation 2000-2006. All Rights Reserved. 

#ifndef testtypeapih
#define testtypeapih

#include <time.h>
// The following ifdef block is the standard way of creating macros which make exporting 
// from a DLL simpler. All files within this DLL are compiled with the TESTTYPEAPI_EXPORTS
// symbol defined on the command line. this symbol should not be defined on any project
// that uses this DLL. This way any other project whose source files include this file see 
// TESTTYPEAPISAMPLE_API functions as being imported from a DLL, wheras this DLL sees symbols
// defined with this macro as being exported.
#ifdef TESTTYPEAPI_EXPORTS
#define TESTTYPEAPI_API __declspec(dllexport)
#else
#define TESTTYPEAPI_API __declspec(dllimport)
#endif


#define TTYPE_MAX_ERROR     	260
#define TTYPE_MAX_ID 		    260
#define TTYPE_MAX_TYPE 	     	260
#define TTYPE_MAX_NAME 		    260
#define TTYPE_MAX_PATH		    260
#define TTYPE_MAX_ACTION_NAME	100

#define TTYPE_SUCCESS						0
#define TTYPE_ERROR_UNABLE_TO_CONNECT		1
#define TTYPE_ERROR_INVALID_SOURCEID		2
#define TTYPE_ERROR_UNABLE_TO_DISCONNECT	3
#define TTYPE_ERROR_INVALID_CONNECTINFO		4
#define TTYPE_ERROR							5
#define TTYPE_CANCEL						6

//These defines are used in the TestOption structure to allow for large script option and Test Tool option values
#define TTYPE_MAX_OPTION_NAME 255
#define TTYPE_MAX_OPTION_VALUE 2048

struct ScriptNode 
{
	TCHAR	Name[TTYPE_MAX_NAME];
	TCHAR	NodeID[TTYPE_MAX_ID];
	TCHAR	Type[TTYPE_MAX_TYPE];
	BOOL	IsOnlyContainer;
	BOOL	IsImplementation;
};

struct ConnectOption 
{
	char	Name[TTYPE_MAX_NAME];
	char	Value[TTYPE_MAX_NAME];
};

struct ScriptOption 
{
	char	Name[TTYPE_MAX_NAME];
	char	Value[TTYPE_MAX_NAME];
};


struct TTAction
{
	TCHAR	Name[TTYPE_MAX_ACTION_NAME];
	int		ActionID;
};

//This structure allows for large values of Test Script Options and Test Tool Options
struct TestOption
{
	char Name[TTYPE_MAX_OPTION_NAME];
	char Value[TTYPE_MAX_OPTION_VALUE];
};


#define TTYPE_SCSTATUS_NOTCONTROLLED	1
#define TTYPE_SCSTATUS_CHECKEDOUT		2
#define TTYPE_SCSTATUS_CHECKEDIN		3
	
	
#define TTYPE_FUNCTION_TTConnect					1
#define TTYPE_FUNCTION_TTDisconnect					2
#define TTYPE_FUNCTION_TTSelect						3
#define TTYPE_FUNCTION_TTEdit						4
#define TTYPE_FUNCTION_TTShowProperties				5
#define TTYPE_FUNCTION_TTRecord						6
#define TTYPE_FUNCTION_TTNew						7
#define TTYPE_FUNCTION_TTGetIcon					8
#define TTYPE_FUNCTION_TTGetName					9
#define TTYPE_FUNCTION_TTCompile					10
#define TTYPE_FUNCTION_TTGetRoots					11
#define TTYPE_FUNCTION_TTGetChildren				12
#define TTYPE_FUNCTION_TTGetNode					13
#define TTYPE_FUNCTION_TTGetSourceIcon				14
#define TTYPE_FUNCTION_TTGetTypeIcon				15
#define TTYPE_FUNCTION_TTGetConfiguration			16
#define TTYPE_FUNCTION_TTGetFilterEx				17
#define TTYPE_FUNCTION_TTGetSourceActions			18
#define TTYPE_FUNCTION_TTGetNodeActions				19
#define TTYPE_FUNCTION_TTSetConfiguration			20
#define TTYPE_FUNCTION_TTSetFilterEx				21
#define TTYPE_FUNCTION_TTExecuteSourceAction		22
#define TTYPE_FUNCTION_TTExecuteNodeAction			23
#define TTYPE_FUNCTION_TTAddToSourceControl			24
#define TTYPE_FUNCTION_TTCheckOut					25
#define TTYPE_FUNCTION_TTCheckIn					26
#define TTYPE_FUNCTION_TTUndoCheckOut				27
#define TTYPE_FUNCTION_TTGetSourceControlStatus		28
#define TTYPE_FUNCTION_TTGetTestToolOptions         29
#define TTYPE_FUNCTION_TTClearFilter				30

//New methods supporting the TestOption structure
#define TTYPE_FUNCTION_TTSelect2					31
#define TTYPE_FUNCTION_TTEdit2						32
#define TTYPE_FUNCTION_TTShowProperties2			33
#define TTYPE_FUNCTION_TTRecord2					34
#define TTYPE_FUNCTION_TTNew2						35
#define TTYPE_FUNCTION_TTCompile2					36
#define TTYPE_FUNCTION_TTGetTestToolOptions2		37



#ifdef TESTTYPEAPI_EXPORTS

TESTTYPEAPI_API HRESULT TTConnect(const char ConnectInfo[TTYPE_MAX_PATH], char UserID[TTYPE_MAX_ID], ConnectOption *pConnectOptions, int nOptions, char SourceID[TTYPE_MAX_ID], char ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTDisconnect(const char SourceID[TTYPE_MAX_ID], char ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTSelect(const char SourceID[TTYPE_MAX_ID], char ScriptID[TTYPE_MAX_ID], char ScriptName[TTYPE_MAX_NAME], ScriptOption *pScriptOptions[], int *nScriptOptions, char ErrorDescription[TTYPE_MAX_ERROR], long lWindowContext);
TESTTYPEAPI_API HRESULT TTEdit(const char SourceID[TTYPE_MAX_ID],const char ScriptID[TTYPE_MAX_ID], int LineNumber, ScriptOption *pScriptOptions[], int* nScriptOptions, char ErrorDescription[TTYPE_MAX_ERROR], long lWindowContext);
TESTTYPEAPI_API HRESULT TTShowProperties(const char SourceID[TTYPE_MAX_ID],const char ScriptID[TTYPE_MAX_ID], ScriptOption *pScriptOptions[], int *nScriptOptions, char ErrorDescription[TTYPE_MAX_ERROR], long lWindowContext);
TESTTYPEAPI_API HRESULT TTRecord(const char SourceID[TTYPE_MAX_ID],const char ScriptID[TTYPE_MAX_ID], ScriptOption *pScriptOptions[], int *nScriptOptions, char ErrorDescription[TTYPE_MAX_ERROR], long lWindowContext);
TESTTYPEAPI_API HRESULT TTNew(const char SourceID[TTYPE_MAX_ID], char ScriptID[TTYPE_MAX_ID], char ScriptName[TTYPE_MAX_NAME], ScriptOption *pScriptOptions[], int *nScriptOptions, char ErrorDescription[TTYPE_MAX_ERROR], long lWindowContext);
TESTTYPEAPI_API HRESULT TTGetIcon(char SourceID[TTYPE_MAX_ID], char IconPath[TTYPE_MAX_PATH], char ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetName(const char SourceID[TTYPE_MAX_ID],const char ScriptID[TTYPE_MAX_ID], char ScriptName[TTYPE_MAX_NAME], char ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTCompile(const char SourceID[TTYPE_MAX_ID], const char ScriptID[TTYPE_MAX_ID], long* plResult, char StatusMessage[TTYPE_MAX_ERROR], TCHAR (** OutputFiles)[TTYPE_MAX_PATH], long *lFileCount, ScriptOption pScriptOptions[], int nScriptOptions, char ErrorDescription[TTYPE_MAX_ERROR]);

// New for OM
TESTTYPEAPI_API HRESULT TTGetRoots(const TCHAR SourceID[TTYPE_MAX_ID], struct ScriptNode *pRootNodes[], long* plNodeCount, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetChildren(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], struct ScriptNode *pChildNodes[], long* plNodeCount, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetNode(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], struct ScriptNode** pNode, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetParent(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], struct ScriptNode** pParentNode, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetNameEx(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], TCHAR Name[TTYPE_MAX_NAME], TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetType(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], TCHAR Type[TTYPE_MAX_TYPE], TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetTypes(const TCHAR SourceID[TTYPE_MAX_ID], TCHAR (** Types)[TTYPE_MAX_TYPE], long* pTypeCount, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetIsParent(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], BOOL* pbIsParent,  TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API BOOL TTGetIsValidSource(const TCHAR SourceID[TTYPE_MAX_ID]);
TESTTYPEAPI_API HRESULT TTGetSourceIcon(const TCHAR SourceID[TTYPE_MAX_ID], TCHAR IconPath[TTYPE_MAX_PATH], TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetTypeIcon(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR Type[TTYPE_MAX_TYPE], TCHAR IconPath[TTYPE_MAX_PATH], TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetIsNode(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], BOOL* pbIsNode, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetIsChild(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], BOOL* pbIsChild, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);

TESTTYPEAPI_API HRESULT TTGetConfiguration(const TCHAR SourceID[TTYPE_MAX_ID], long lWindowContext, TCHAR **pConfigurationBuffer, int* pnConfigurationBufferLength, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetFilterEx(const TCHAR SourceID[TTYPE_MAX_ID], long lWindowContext, TCHAR **pFilterBuffer, int* pnFilterBufferLength, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetSourceActions(const TCHAR SourceID[TTYPE_MAX_ID], struct TTAction *pActions[], int *pnActionCount, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetNodeActions(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR Type[TTYPE_MAX_TYPE], struct TTAction *pActions[], int *pnActionCount, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTSetConfiguration(const TCHAR SourceID[TTYPE_MAX_ID], TCHAR *pConfigurationBuffer, int nConfigurationBufferLength, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTSetFilterEx(const TCHAR SourceID[TTYPE_MAX_ID], TCHAR *pFilterBuffer, int nFilterBufferLength, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTExecuteSourceAction(const TCHAR SourceID[TTYPE_MAX_ID], int nActionID, long lWindowContext, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTExecuteNodeAction(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], int nActionID, long lWindowContext, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);

TESTTYPEAPI_API HRESULT TTAddToSourceControl(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], long lWindowContext, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTCheckOut(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], long lWindowContext, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTCheckIn(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], long lWindowContext, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTUndoCheckOut(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], long lWindowContext, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetSourceControlStatus(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], long *plStatus, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);

TESTTYPEAPI_API HRESULT TTGetIsFunctionSupported(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], long lFunctionID, BOOL *pbIsSupported, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetTestToolOptions(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], long lWindowContext, struct ScriptOption *pOptions[], int* piCount, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTClearFilter(const TCHAR SourceID[TTYPE_MAX_ID], TCHAR ErrorDescription[TTYPE_MAX_ERROR]);

//New methods using the expanded TestOption structure
TESTTYPEAPI_API HRESULT TTSelect2(const char SourceID[TTYPE_MAX_ID], char ScriptID[TTYPE_MAX_ID], char ScriptName[TTYPE_MAX_NAME], TestOption *pTestOptions[], int *nTestOptions, char ErrorDescription[TTYPE_MAX_ERROR], long lWindowContext);
TESTTYPEAPI_API HRESULT TTEdit2(const char SourceID[TTYPE_MAX_ID],const char ScriptID[TTYPE_MAX_ID], int LineNumber, TestOption *pTestOptions[], int* nTestOptions, char ErrorDescription[TTYPE_MAX_ERROR], long lWindowContext);
TESTTYPEAPI_API HRESULT TTShowProperties2(const char SourceID[TTYPE_MAX_ID],const char ScriptID[TTYPE_MAX_ID], TestOption *pTestOptions[], int *nTestOptions, char ErrorDescription[TTYPE_MAX_ERROR], long lWindowContext);
TESTTYPEAPI_API HRESULT TTRecord2(const char SourceID[TTYPE_MAX_ID],const char ScriptID[TTYPE_MAX_ID], TestOption *pTestOptions[], int *nTestOptions, char ErrorDescription[TTYPE_MAX_ERROR], long lWindowContext);
TESTTYPEAPI_API HRESULT TTNew2(const char SourceID[TTYPE_MAX_ID], char ScriptID[TTYPE_MAX_ID], char ScriptName[TTYPE_MAX_NAME], TestOption *pTestOptions[], int *nTestOptions, char ErrorDescription[TTYPE_MAX_ERROR], long lWindowContext);
TESTTYPEAPI_API HRESULT TTCompile2(const char SourceID[TTYPE_MAX_ID], const char ScriptID[TTYPE_MAX_ID], long* plResult, char StatusMessage[TTYPE_MAX_ERROR], TCHAR (** OutputFiles)[TTYPE_MAX_PATH], long *lFileCount, TestOption pTestOptions[], int nTestOptions, char ErrorDescription[TTYPE_MAX_ERROR]);
TESTTYPEAPI_API HRESULT TTGetTestToolOptions2(const TCHAR SourceID[TTYPE_MAX_ID], const TCHAR NodeID[TTYPE_MAX_ID], long lWindowContext, struct TestOption *pOptions[], int* piCount, TCHAR ErrorDescription[TTYPE_MAX_ERROR]);


#endif
#endif